# assets.py  ← drop this next to utils/, purge.py, etc.
from haraka.art.ascii.assets import *

go_emoji_logo = [
    emoji["go"]
]
go_performance_mode = [
    goLang,
    divider_xl,
    performance_mode,
    divider_l,
    tools,
    divider_s,
    gRPC,
    divider_mono,
    protoC,
    divider_mono,
    autoMaxProcs,
    divider_mono,
    ants,
    divider_mono,
    zeroLog,
]
go_fast = [
    goFast,
    gRpc_ProtoBuf,
    server,
    by,
    wjb_dev
]